"""Read the mongodb database content."""

import argparse
import json
from pathlib import Path
from typing import List, Optional, Tuple

import requests
from pymongo import MongoClient


def parse_args(argv: Optional[List[str]] = None) -> Tuple[str, Path]:
    """Parse arguments for the command line parser."""
    parser = argparse.ArgumentParser(
        description="Read mongodb for file patterns.",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )
    parser.add_argument(
        "vault_url",
        type=str,
        help="The address for the vault server to read the screts from.",
    )
    parser.add_argument(
        "output",
        type=Path,
        help="Where should the result of the mongodb query be saved to.",
    )
    args = parser.parse_args(argv)
    return args.vault_url, args.output


def get_mongo_url(vault_url: str) -> str:
    """Construct the mongodb url from the vault."""
    res = requests.get(vault_url, timeout=3)
    res.raise_for_status()
    content = res.json()
    return content.get("mongo.url", "")


if __name__ == "__main__":
    vault_url, output_file = parse_args()
    client = MongoClient(get_mongo_url(vault_url))
    collection = client["plugins"]["zonk"]
    result = collection.find_one() or {"file_pattern": []}

    output_file.write_text(
        json.dumps({"file_pattern": result.get("file_pattern", [])})
    )
